#!/bin/bash

set -e

# Created 2024-11-03 14:18:00

CASEDIR="/pscratch/sd/h/huiwan/vis/ncic/cases_202411/v2_F2010_nc00_freq/case_scripts"

/global/cfs/projectdirs/m4792/huiwan/vis/ncic/code/maint-2.0_CondiDiag1.0_cdnc/cime/scripts/create_newcase --case v2_F2010_nc00_freq --output-root /pscratch/sd/h/huiwan/vis/ncic/cases_202411/v2_F2010_nc00_freq --script-root "${CASEDIR}" --handle-preexisting-dirs u --compset F2010 --res ne30pg2_oECv3 --machine pm-cpu --project m4792 --walltime 8:00:00 --pecount S

cd "${CASEDIR}"

./xmlchange EXEROOT=/pscratch/sd/h/huiwan/vis/ncic/cases_202411/v2_F2010_nc00_freq/build

./xmlchange RUNDIR=/pscratch/sd/h/huiwan/vis/ncic/cases_202411/v2_F2010_nc00_freq/run

./xmlchange DOUT_S=FALSE

./xmlchange DOUT_S_ROOT=/pscratch/sd/h/huiwan/vis/ncic/cases_202411/v2_F2010_nc00_freq/archive

./xmlchange --id CAM_CONFIG_OPTS --append --val=-cosp

./case.setup --reset

./case.build

./preview_namelists

./xmlchange RUN_STARTDATE=2009-09-01

./xmlchange STOP_OPTION=nmonths,STOP_N=16

./xmlchange REST_OPTION=nmonths,REST_N=4

./xmlchange HIST_OPTION=nyears,HIST_N=5

./xmlchange BUDGETS=TRUE

./xmlchange RUN_TYPE=startup

./xmlchange CONTINUE_RUN=FALSE

./case.submit

