  atm2ice_fmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_oEC60to30v3_mono.200220.nc"
  atm2ice_fmaptype: "X"
  atm2ice_smapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_oEC60to30v3_bilin.200220.nc"
  atm2ice_smaptype: "X"
  atm2ice_vmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_oEC60to30v3_bilin.200220.nc"
  atm2ice_vmaptype: "X"
  atm2lnd_fmapname: "idmap"
  atm2lnd_fmaptype: "X"
  atm2lnd_smapname: "idmap"
  atm2lnd_smaptype: "X"
  atm2ocn_fmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_oEC60to30v3_mono.200220.nc"
  atm2ocn_fmaptype: "X"
  atm2ocn_smapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_oEC60to30v3_bilin.200220.nc"
  atm2ocn_smaptype: "X"
  atm2ocn_vmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_oEC60to30v3_bilin.200220.nc"
  atm2ocn_vmaptype: "X"
  atm2rof_fmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_r05_mono.200220.nc"
  atm2rof_fmaptype: "X"
  atm2rof_smapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_r05_mono.200220.nc"
  atm2rof_smaptype: "X"
  atm2wav_smapname: "idmap"
  atm2wav_smaptype: "X"
  glc2ice_fmapname: "idmap_ignore"
  glc2ice_fmaptype: "X"
  glc2ice_rmapname: "idmap_ignore"
  glc2ice_rmaptype: "X"
  glc2ice_smapname: "idmap_ignore"
  glc2ice_smaptype: "X"
  glc2lnd_fmapname: "idmap"
  glc2lnd_fmaptype: "X"
  glc2lnd_smapname: "idmap"
  glc2lnd_smaptype: "X"
  glc2ocn_fmapname: "idmap_ignore"
  glc2ocn_fmaptype: "X"
  glc2ocn_ice_rmapname: "idmap_ignore"
  glc2ocn_ice_rmaptype: "X"
  glc2ocn_liq_rmapname: "idmap_ignore"
  glc2ocn_liq_rmaptype: "X"
  glc2ocn_smapname: "idmap_ignore"
  glc2ocn_smaptype: "X"
  iac2atm_fmapname: "idmap"
  iac2atm_fmaptype: "X"
  iac2atm_smapname: "idmap"
  iac2atm_smaptype: "X"
  iac2lnd_fmapname: "idmap"
  iac2lnd_fmaptype: "X"
  iac2lnd_smapname: "idmap"
  iac2lnd_smaptype: "X"
  ice2atm_fmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/oEC60to30v3/map_oEC60to30v3_to_ne30pg2_mono.200220.nc"
  ice2atm_fmaptype: "X"
  ice2atm_smapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/oEC60to30v3/map_oEC60to30v3_to_ne30pg2_mono.200220.nc"
  ice2atm_smaptype: "X"
  ice2wav_smapname: "idmap"
  ice2wav_smaptype: "X"
  lnd2atm_fmapname: "idmap"
  lnd2atm_fmaptype: "X"
  lnd2atm_smapname: "idmap"
  lnd2atm_smaptype: "X"
  lnd2glc_fmapname: "idmap"
  lnd2glc_fmaptype: "X"
  lnd2glc_smapname: "idmap"
  lnd2glc_smaptype: "X"
  lnd2rof_fmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_ne30pg2_to_r05_mono.200220.nc"
  lnd2rof_fmaptype: "X"
  ocn2atm_fmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/oEC60to30v3/map_oEC60to30v3_to_ne30pg2_mono.200220.nc"
  ocn2atm_fmaptype: "X"
  ocn2atm_smapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/oEC60to30v3/map_oEC60to30v3_to_ne30pg2_mono.200220.nc"
  ocn2atm_smaptype: "X"
  ocn2glc_fmapname: "idmap_ignore"
  ocn2glc_fmaptype: "X"
  ocn2glc_smapname: "idmap_ignore"
  ocn2glc_smaptype: "X"
  ocn2wav_smapname: "idmap"
  ocn2wav_smaptype: "X"
  rof2lnd_fmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/gridmaps/ne30pg2/map_r05_to_ne30pg2_mono.200220.nc"
  rof2lnd_fmaptype: "X"
  rof2ocn_fmapname: "idmap_ignore"
  rof2ocn_fmaptype: "X"
  rof2ocn_ice_rmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/cpl6/map_r05_to_oEC60to30v3_smoothed.r300e600.161222.nc"
  rof2ocn_ice_rmaptype: "X"
  rof2ocn_liq_rmapname: "/global/cfs/cdirs/e3sm/inputdata/cpl/cpl6/map_r05_to_oEC60to30v3_smoothed.r300e600.161222.nc"
  rof2ocn_liq_rmaptype: "X"
  wav2ocn_smapname: "idmap"
  wav2ocn_smaptype: "X"
